mezmorize: A python function memoization library heavily inspired by Flask-Cache.
=================================================================================

|travis| |versions| |pypi|

License
-------

``mezmorize`` is distributed under the `BSD License`_.

.. |travis| image:: https://img.shields.io/travis/reubano/mezmorize/master.svg
    :target: https://travis-ci.org/reubano/mezmorize

.. |versions| image:: https://img.shields.io/pypi/pyversions/mezmorize.svg
    :target: https://pypi.python.org/pypi/mezmorize

.. |pypi| image:: https://img.shields.io/pypi/v/mezmorize.svg
    :target: https://pypi.python.org/pypi/mezmorize

.. _BSD License: http://opensource.org/licenses/BSD-3-Clause
